let express = require('express');
let router = express.Router();
const { PrismaClient } = require('@prisma/client');
const prisma = new PrismaClient();


router.get('/team', async (req, res) => {
    const teams = await prisma.team.findMany({
        include: { players: true },
    });
    res.json(teams);
})

router.post('/team', async (req, res) => {
    if ( req.body.hasOwnProperty("teamName")
        && req.body.hasOwnProperty("location")) {
        const { teamName, location } = req.body;
        const newTeam = await prisma.team.create({
            data: { teamName, location },
        });
        res.json({ success: "ok", message: "team added", team: newTeam});
    } else {
        res.json({ success: "error", message: "attributes missing"});
    }
});

router.post('/player', async (req, res) => {
    if ( req.body.hasOwnProperty("playerName")
        && req.body.hasOwnProperty("role")
        && req.body.hasOwnProperty("teamId")) {
        const { playerName, role, teamId } = req.body;
        const newPlayer = await prisma.player.create({
            data: { playerName, role, teamId },
        });
        res.json({ success: "ok", message: "player added", player: newPlayer});
    } else {
        res.json({ success: "error", message: "attributes missing"});
    }
});

router.delete('/player/:id', async (req, res) => {
    const { id } = req.params;
    await prisma.team.delete({
        where: { id },
    });
    res.json({ success: "ok", message: "team deleted"});
});

router.delete('/players/:id', async (req, res) => {
    const { id } = req.params;
    await prisma.player.delete({
        where: { id },
    });
    res.json({ success: "ok", message: "player deleted"});
});

module.exports = router;